@@ -293,7 +293,7 @@ def initialize(args):
 
 
 def rollback_installation(args):
-    #os.exit(1)
+    os.exit(1)
     workpath = "{prefix}/{pt}/{prgname}".format(
         prefix=os.path.abspath(args.install_prefix), pt=str(args.port), prgname=str(args.prog_name)
     )
