@@ -1,11 +1,12 @@
 #!/bin/sh
 
-if [ $# -ne 1 ];then
-   echo "usage: $0 port"
+if [ $# -eq 0 ];then
+   echo "usage: $0 port [shutdown_timeout]"
    exit
 fi
 
 port=$1
+stimeout=${2:-60}
 base_dir=`dirname "$PWD"`
 export LD_LIBRARY_PATH="$base_dir/lib:$LD_LIBRARY_PATH"
 
@@ -26,7 +27,7 @@ fi
 
 sockfile=` grep "^socket *=" ${etcfile}  | tail -n1| awk -F"=" '{print $2}'`
 
-$base_dir/bin/mysqladmin --shutdown-timeout=30 shutdown -S ${sockfile} -uroot -proot
+$base_dir/bin/mysqladmin --shutdown-timeout=${stimeout} --connect-timeout=60 shutdown -S ${sockfile} -uroot -proot
 
 programe="bin/mysqld"
 cmd="ps -ef | grep ${programe} | grep -v vim | grep -v grep | grep -v defunct | grep -- '/${port}.cnf' | awk '{print \$2}' | head -n 1"
